:github_url: https://github.com/merlinquantum/merlin

.. _quickstart:

==========
Quickstart
==========

.. toctree::
   :maxdepth: 2
   :caption: Table of Contents

   installation
   first_quantum_layer
   basic_concepts
